OpenAiAdapter

Struct OpenAiAdapter 

pub struct OpenAiAdapter { /* private fields */ }
Adapter for the OpenAI Responses API.

Converts internal Chat Completions payloads to the Responses API format and converts responses back to Chat Completions format.

Implementations

Source

impl OpenAiAdapter

pub fn new() -> Self

Create a new OpenAI adapter with the default Responses API URL.

pub fn with_url(url: impl Into<String>) -> Self

Create with a custom API URL (for Azure, proxies, etc.).